==> basic-1.0.7-sources.jar: net/oschina/suyeer/basic/util/BasicUtil.java <==
package net.oschina.suyeer.basic.util;

import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;

import javax.servlet.http.HttpServletRequest;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.List;
import java.util.UUID;

/**
 * Created by jun on 2017/2/15.
 */
public class BasicUtil {

    private static Logger logger = Logger.getLogger(BasicUtil.class);

    public static String getUserIp(HttpServletRequest request) {
        String ipAddress = request.getHeader("x-forwarded-for");
        if (ipAddress == null || ipAddress.length() == 0 || "unknown".equalsIgnoreCase(ipAddress)) {
            ipAddress = request.getHeader("Proxy-Client-IP");
        }
        if (ipAddress == null || ipAddress.length() == 0 || "unknown".equalsIgnoreCase(ipAddress)) {
            ipAddress = request.getHeader("WL-Proxy-Client-IP");
        }
        if (ipAddress == null || ipAddress.length() == 0 || "unknown".equalsIgnoreCase(ipAddress)) {
            ipAddress = request.getRemoteAddr();
            if (ipAddress.equals("127.0.0.1") || ipAddress.equals("0:0:0:0:0:0:0:1")) {
                InetAddress ine = null;
                try {
                    ine = InetAddress.getLocalHost();
                } catch (UnknownHostException e) {
                    logger.error("获取用户ip失败 : " + e.getMessage());
                }
                ipAddress = ine.getHostAddress();
            }
        }
        if (ipAddress != null && ipAddress.length() > 15) {
            if (ipAddress.indexOf(",") > 0) {
                ipAddress = ipAddress.substring(0, ipAddress.indexOf(","));
            }
        }
        return ipAddress;
    }

    public static String getUUID() {
        return UUID.randomUUID().toString();
    }

    public static String getNonceStr() {
        return BEncryptUtil.MD5(getUUID());
    }

    public static List<String> getList(String srcStr) {
        return getList(srcStr, ",");
    }

    public static List<String> getList(String srcStr, String separatorStr) {
        List<String> retList = new ArrayList<>();
        if (StringUtils.isNotBlank(srcStr) && StringUtils.isNotBlank(separatorStr)) {
            String arr[] = srcStr.split(separatorStr);
            for (String s : arr) {
                if (StringUtils.isNotBlank(s)) {
                    retList.add(s.trim());
                }
            }
        }
        return retList;
    }

}

==> basic-1.0.8-sources.jar: net/oschina/suyeer/basic/util/BasicUtil.java <==
package net.oschina.suyeer.basic.util;

import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;

import javax.servlet.http.HttpServletRequest;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.List;
import java.util.UUID;

/**
 * Created by jun on 2017/2/15.
 */
public class BasicUtil {

    private static Logger logger = Logger.getLogger(BasicUtil.class);

    public static String getUserIp(HttpServletRequest request) {
        String ipAddress = request.getHeader("x-forwarded-for");
        if (ipAddress == null || ipAddress.length() == 0 || "unknown".equalsIgnoreCase(ipAddress)) {
            ipAddress = request.getHeader("Proxy-Client-IP");
        }
        if (ipAddress == null || ipAddress.length() == 0 || "unknown".equalsIgnoreCase(ipAddress)) {
            ipAddress = request.getHeader("WL-Proxy-Client-IP");
        }
        if (ipAddress == null || ipAddress.length() == 0 || "unknown".equalsIgnoreCase(ipAddress)) {
            ipAddress = request.getRemoteAddr();
            if (ipAddress.equals("127.0.0.1") || ipAddress.equals("0:0:0:0:0:0:0:1")) {
                InetAddress ine = null;
                try {
                    ine = InetAddress.getLocalHost();
                } catch (UnknownHostException e) {
                    logger.error("获取用户ip失败!", e);
                }
                ipAddress = ine.getHostAddress();
            }
        }
        if (ipAddress != null && ipAddress.length() > 15) {
            if (ipAddress.indexOf(",") > 0) {
                ipAddress = ipAddress.substring(0, ipAddress.indexOf(","));
            }
        }
        return ipAddress;
    }

    public static String getUUID() {
        return UUID.randomUUID().toString();
    }

    public static String getNonceStr() {
        return BEncryptUtil.MD5(getUUID());
    }

    public static List<String> getList(String srcStr) {
        return getList(srcStr, ",");
    }

    public static List<String> getList(String srcStr, String separatorStr) {
        List<String> retList = new ArrayList<>();
        if (StringUtils.isNotBlank(srcStr) && StringUtils.isNotBlank(separatorStr)) {
            String arr[] = srcStr.split(separatorStr);
            for (String s : arr) {
                if (StringUtils.isNotBlank(s)) {
                    retList.add(s.trim());
                }
            }
        }
        return retList;
    }

}
